pub struct BindContext {
pub params: HashMap<SmolStr, TypedValue>,
pub env: HashMap<SmolStr, TypedValue>,
}Expand description
Bind-time context: parameter values and environment variables.
The Cypher evaluator is treated like a virtual machine — it accepts a query string plus two context maps that are resolved to literals during binding:
params:$paramplaceholders →TypedValueenv:env('KEY')lookups →TypedValue
Fields
params: HashMap<SmolStr, TypedValue>env: HashMap<SmolStr, TypedValue>Implementations
Sourceimpl BindContext
impl BindContext
pub fn empty() -> BindContext
Sourcepub fn with_params_json(params: Value) -> BindContext
pub fn with_params_json(params: Value) -> BindContext
Build a context with params from a serde_json::Value object.
use serde_json::json;
let ctx = BindContext::with_params_json(json!({"min_age": 25, "name": "Alice"}));Sourcepub fn with_env_json(env: Value) -> BindContext
pub fn with_env_json(env: Value) -> BindContext
Build a context with env from a serde_json::Value object.
use serde_json::json;
let ctx = BindContext::with_env_json(json!({"DATA_DIR": "/data"}));Sourcepub fn from_json(params: Value, env: Value) -> BindContext
pub fn from_json(params: Value, env: Value) -> BindContext
Build a full context from two serde_json::Value objects.
Sourcepub fn with_params_str(json: &str) -> Result<BindContext, Error>
pub fn with_params_str(json: &str) -> Result<BindContext, Error>
Build a context with params parsed from a JSON string.
Returns Err if the string is not valid JSON.
Sourcepub fn with_env_str(json: &str) -> Result<BindContext, Error>
pub fn with_env_str(json: &str) -> Result<BindContext, Error>
Build a context with env parsed from a JSON string.
Returns Err if the string is not valid JSON.
Sourcepub fn from_json_str(params: &str, env: &str) -> Result<BindContext, Error>
pub fn from_json_str(params: &str, env: &str) -> Result<BindContext, Error>
Build a full context from two JSON strings.
Returns Err if either string is not valid JSON.